@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.91 date 2003-12-29
+ * version 0.92 date 2004-04-07
  * Copyright (C) 2003 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -65,9 +65,9 @@ typedef struct s_proto_mcuf_hdr
 #define BLP_CLOSE "\xDE""\xAA""\xBF""\xCD""CLOSE"
 #define BLP_CLOSE_LEN 9
 #define EBLP_CLOSE "\xDE""\xAA""\xBF""\xCD""CLOSE256"
-#define EBLP_CLOSE_LEN 9
-#define MCUF_CLOSE ""
-#define MCUF_CLOSE_LEN 0
+#define EBLP_CLOSE_LEN 12
+#define MCUF_CLOSE "\x42""\x42""\x42""\x43""\0\0\0\0\0\0\0\0"
+#define MCUF_CLOSE_LEN 12
 
 
 
